# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_active_account import PageActiveAccount

class TestPageActiveAccount(unittest.TestCase):
    """PageActiveAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageActiveAccount:
        """Test PageActiveAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageActiveAccount`
        """
        model = PageActiveAccount()
        if include_optional:
            return PageActiveAccount(
                first = '',
                items = [
                    wordlift_client.models.active_account.ActiveAccount(
                        country = '', 
                        diagnostic_plugins = [
                            wordlift_client.models.diagnostic_plugin.DiagnosticPlugin(
                                account_id = 56, 
                                active = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = 56, 
                                name = '', 
                                version = '', )
                            ], 
                        domain_uri = '', 
                        google_search_console_site_url = '', 
                        id = 56, 
                        is_wordpress = True, 
                        key = '', 
                        language = '', 
                        ng_dataset_id = '', 
                        package_type = '', 
                        subscription = wordlift_client.models.account_subscription.AccountSubscription(
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            order_id = 56, 
                            sku = '', ), 
                        subscription_id = 56, 
                        total_entities = 56, 
                        total_entities_with_schema_url = 56, 
                        url = '', 
                        user_id = 56, 
                        wp_admin = '', 
                        wp_include_exclude_default = '', 
                        wp_json = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageActiveAccount(
                first = '',
                items = [
                    wordlift_client.models.active_account.ActiveAccount(
                        country = '', 
                        diagnostic_plugins = [
                            wordlift_client.models.diagnostic_plugin.DiagnosticPlugin(
                                account_id = 56, 
                                active = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = 56, 
                                name = '', 
                                version = '', )
                            ], 
                        domain_uri = '', 
                        google_search_console_site_url = '', 
                        id = 56, 
                        is_wordpress = True, 
                        key = '', 
                        language = '', 
                        ng_dataset_id = '', 
                        package_type = '', 
                        subscription = wordlift_client.models.account_subscription.AccountSubscription(
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            order_id = 56, 
                            sku = '', ), 
                        subscription_id = 56, 
                        total_entities = 56, 
                        total_entities_with_schema_url = 56, 
                        url = '', 
                        user_id = 56, 
                        wp_admin = '', 
                        wp_include_exclude_default = '', 
                        wp_json = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageActiveAccount(self):
        """Test PageActiveAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
