# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.get_entities200_response import GetEntities200Response

class TestGetEntities200Response(unittest.TestCase):
    """GetEntities200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetEntities200Response:
        """Test GetEntities200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEntities200Response`
        """
        model = GetEntities200Response()
        if include_optional:
            return GetEntities200Response(
            )
        else:
            return GetEntities200Response(
        )
        """

    def testGetEntities200Response(self):
        """Test GetEntities200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
