# coding: utf-8

"""
    SEO Content Analysis API

    This API assesses the match between a URL or text content, a query, and an intent, using advanced SEO techniques.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.account_stats import AccountStats

class TestAccountStats(unittest.TestCase):
    """AccountStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountStats:
        """Test AccountStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccountStats`
        """
        model = AccountStats()
        if include_optional:
            return AccountStats(
                entities_with_url = 56,
                product_groups = 56,
                products = 56
            )
        else:
            return AccountStats(
                entities_with_url = 56,
                product_groups = 56,
                products = 56,
        )
        """

    def testAccountStats(self):
        """Test AccountStats"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
